
import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTextArea;

public class MultiEditor {


	JButton openButton;
	JButton saveButton;
	JPanel mainPanel;
	JTextArea textArea;
	
	Document editedText;

	public MultiEditor()
	{
		this(new Document());
	}

	MultiEditor(Document editedText)
	{
		this.editedText = editedText;	
		buildUI();
		buildButtonListener();
		buildTextAreaListener();
		update();
	}

	private void buildTextAreaListener() {
		textArea.addKeyListener(new KeyListener() { // anonymous inner class implementing KeyListener
													// has access to members of this (e.g. textArea)
			public void keyReleased(KeyEvent e) {
				editedText.setText(textArea.getText());
			}
			
			public void keyTyped(KeyEvent e) {/*do nothing*/ }
			public void keyPressed(KeyEvent e) { /*do nothing*/ }
		});
	}

	private void buildButtonListener() {
		openButton.addActionListener(
				new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				JFileChooser fileopen = new JFileChooser();
			    int ret = fileopen.showDialog(null, "Open file");

			    if (ret == JFileChooser.APPROVE_OPTION) {
			      File file = fileopen.getSelectedFile();
			      String filename = file.getAbsolutePath();
			      BufferedReader br;
			      try {
			    	  br = new BufferedReader(new FileReader(filename));
			    	  String line;
			    	  String text = "";
				      	while((line = br.readLine()) != null){
				      		text += line;
				        }
				      br.close();
				      textArea.setText(text);
					} catch (FileNotFoundException e1) {
						// TODO Auto-generated catch block
						e1.printStackTrace();
					} catch (IOException e1) {
						// TODO Auto-generated catch block
						e1.printStackTrace();
					} 
			    }
			}
		});
		
		saveButton.addActionListener(
				new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				JFileChooser fileopen = new JFileChooser();
			    int ret = fileopen.showDialog(null, "Save file");
			   
			      File file = fileopen.getSelectedFile();
			      System.out.println(file);
			      String filename = file.getAbsolutePath();
			      BufferedWriter bw;
			      try {
			    	  bw = new BufferedWriter(new FileWriter(filename));
			    	  String text = textArea.getText();
				      bw.write(text);
				      bw.close();
					} catch (FileNotFoundException e1) {
						// TODO Auto-generated catch block
						e1.printStackTrace();
					} catch (IOException e1) {
						// TODO Auto-generated catch block
						e1.printStackTrace();
					} 
			    
			}
		});
	}

	private void buildUI() {
		JFrame frame = new JFrame("Paint");
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		mainPanel = new JPanel(new BorderLayout());
		textArea = new JTextArea(80,80);
		openButton = new JButton("Open");
		saveButton = new JButton("Save");
		mainPanel.add(openButton, BorderLayout.NORTH);
		mainPanel.add(saveButton, BorderLayout.SOUTH);
		mainPanel.add(textArea, BorderLayout.CENTER);
		frame.getContentPane().add(mainPanel);
		frame.setSize(640,480);
		frame.setVisible(true);
	}

	public void update() {
		String editedString = editedText.getText();
		if(!editedString.equals(textArea.getText())) {
			this.textArea.setText(editedString);
		}
		
	}

	public static void main(String[] args) {
		new MultiEditor();
	}

}

